pub enum Error {
NotConnected,
Initialization,
MonoBackground,
MonoText,
ColorBackground,
ColorTitle,
ColorText,
NullCharacter,
LoadLibrary(Error),
}Expand description
Runtime LCD error
The underling Logitech LCD/GamePanel SDK does unfortunately not return any info on error. We therefore only able report what function failed, but not why.
Variants
NotConnected
A logitech LCD is not connected to the system.
Initialization
FFI call to LogiLcdInit() in LogitechLcd.dll has failed.
MonoBackground
FFI call to LogiLcdMonoSetBackground() in LogitechLcd.dll has failed.
MonoText
FFI call to LogiLcdMonoSetText() in LogitechLcd.dll has failed.
ColorBackground
FFI call to LogiLcdColorSetBackground() in LogitechLcd.dll has failed.
ColorTitle
FFI call to LogiLcdColorSetTitle() in LogitechLcd.dll has failed.
ColorText
FFI call to LogiLcdColorSetText() in LogitechLcd.dll has failed.
NullCharacter
Unexpected NULL character
LoadLibrary(Error)
Failed to load LogitechLcd.dll.